ChunkedArchiveOptions

Enum ChunkedArchiveOptions 

pub enum ChunkedArchiveOptions {
    V2 {
        minimum_chunk_size: usize,
        chunk_alignment: usize,
        compression_level: i32,
    },
    V3 {
        compression_algorithm: CompressionAlgorithm,
    },
}
Options for constructing a chunked archive.

Variants



V2

A chunked-compression V2 archive will be created.

Fields

minimum_chunk_size: usize

Chunked-compression V2 has a limit of 1023 chunks. If splitting the data up into minimum_chunk_sized chunks would exceed this limit then the chunk size increased by chunk_alignment until fewer than 1024 are required. minimum_chunk_size must be a multiple of chunk_alignment.

chunk_alignment: usize

The chosen uncompressed chunk size must always be a multiple of this value.

compression_level: i32

The Zstd compression level to use when compressing chunks.



V3

A chunked-compression V3 archive will be created.

Fields

compression_algorithm: CompressionAlgorithm

The compression algorithm to use to compress the chunks.

Implementations

Source

impl ChunkedArchiveOptions

pub fn compressor(&self) -> Compressor

Constructs a compressor to compress chunks based on the specified options.

pub fn thread_local_compressor(&self) -> ThreadLocalCompressor

Constructs a compressor object that uses a thread local compressor to compress chunks based on the specified options.