decode_archive

Function decode_archive 

pub fn decode_archive(
    data: &[u8],
    archive_length: usize,
) -> Result<Option<(DecodedArchive, &[u8])>, ChunkedArchiveError>
Decodes a chunked archive header. Returns a DecodedArchive and any remaining bytes that are part of the chunk data. Returns Ok(None) if data is not large enough to decode the archive header & seek table.