pub struct ChunkedDecompressor { /* private fields */ }Expand description
Streaming decompressor for chunked archives. Example:
// Create a chunked archive:
let data: Vec<u8> = vec![3; 1024];
let compressed = ChunkedArchive::new(&data, /*block_size*/ 8192).serialize().unwrap();
// Verify the header + decode the seek table:
let (seek_table, archive_data) = decode_archive(&compressed, compressed.len())?.unwrap();
let mut decompressed: Vec<u8> = vec![];
let mut on_chunk = |data: &[u8]| { decompressed.extend_from_slice(data); };
let mut decompressor = ChunkedDecompressor(seek_table);
// `on_chunk` is invoked as each slice is made available. Archive can be provided as chunks.
decompressor.update(archive_data, &mut on_chunk);
assert_eq!(data.as_slice(), decompressed.as_slice());Implementations
Sourceimpl ChunkedDecompressor
impl ChunkedDecompressor
Sourcepub fn new(decoded_archive: DecodedArchive) -> Result<Self, ChunkedArchiveError>
pub fn new(decoded_archive: DecodedArchive) -> Result<Self, ChunkedArchiveError>
Create a new decompressor to decode an archive from a validated seek table.
Sourcepub fn new_with_error_handler(
decoded_archive: DecodedArchive,
error_handler: Box<dyn Fn(usize, ChunkInfo, &[u8]) + Send + 'static>,
) -> Result<Self, ChunkedArchiveError>
pub fn new_with_error_handler( decoded_archive: DecodedArchive, error_handler: Box<dyn Fn(usize, ChunkInfo, &[u8]) + Send + 'static>, ) -> Result<Self, ChunkedArchiveError>
Creates a new decompressor with an additional error handler invoked when a chunk fails to be decompressed.
pub fn seek_table(&self) -> &Vec<ChunkInfo>