CompressionInfo

Struct CompressionInfo 

pub struct CompressionInfo { /* private fields */ }

Implementations

Source

impl CompressionInfo

pub fn new( chunk_size: u64, compressed_size: u64, offsets: &[u64], compression_algorithm: CompressionAlgorithm, ) -> Result<Self, ChunkedArchiveError>

pub fn chunk_size(&self) -> u64

Returns the chunk size for this compressed blob.

pub fn compressed_size(&self) -> u64

Returns the total compressed size of this blob.

pub fn compressed_range_for_uncompressed_range( &self, range: &Range<u64>, ) -> Result<Range<u64>, ChunkedArchiveError>

Returns the compressed range for the specified uncompressed range.

pub fn decompress<'a>( &self, src: impl Into<PtrByteSlice<'a>>, dst: &mut [u8], dst_start_offset: u64, ) -> Result<(), ChunkedArchiveError>

Decompress the bytes of src into dst.

  • src is allowed to span multiple chunks.
  • dst must have the exact size of the uncompressed bytes.
  • dst_start_offset is the location of the uncompressed bytes within the blob and must be chunk aligned. This is necessary for determining the chunk boundaries in src.