pub struct DeliveryBlob {
pub header: DeliveryBlobHeader,
pub payload_length: usize,
pub is_compressed: bool,
}Expand description
Untyped header + metadata fields of an RFC 0207 delivery blob.
Fields
header: DeliveryBlobHeaderpayload_length: usizeis_compressed: boolImplementations
Sourceimpl DeliveryBlob
impl DeliveryBlob
Sourcepub fn parse(
data: &[u8],
allow_type3: bool,
) -> Result<Option<(DeliveryBlob, &[u8])>, DeliveryBlobError>
pub fn parse( data: &[u8], allow_type3: bool, ) -> Result<Option<(DeliveryBlob, &[u8])>, DeliveryBlobError>
Attempt to parse data as a delivery blob. On success, returns validated blob info,
and the remainder of data representing the blob payload.
If allow_type3 is false, Type 3 delivery blobs will return
DeliveryBlobError::InvalidType.
Sourcepub fn decompressed_size(delivery_blob: &[u8]) -> Result<u64, DecompressError>
pub fn decompressed_size(delivery_blob: &[u8]) -> Result<u64, DecompressError>
Return the decompressed size of the blob without decompressing it.
Sourcepub fn decompress(delivery_blob: &[u8]) -> Result<Vec<u8>, DecompressError>
pub fn decompress(delivery_blob: &[u8]) -> Result<Vec<u8>, DecompressError>
Decompress a delivery blob in delivery_blob.
Sourcepub fn decompress_to(
delivery_blob: &[u8],
writer: impl Write,
) -> Result<(), DecompressError>
pub fn decompress_to( delivery_blob: &[u8], writer: impl Write, ) -> Result<(), DecompressError>
Decompress a delivery blob in delivery_blob to writer.