Type1Blob

Struct Type1Blob 

pub struct Type1Blob {
    pub header: DeliveryBlobHeader,
    pub payload_length: usize,
    pub is_compressed: bool,
}
Header + metadata fields of a Type 1 blob.

WARNING: Outside of storage-owned components, this should only be used for informational or debugging purposes. The contents of this struct should be considered internal implementation details and are subject to change at any time.

Fields

header: DeliveryBlobHeaderpayload_length: usizeis_compressed: bool

Implementations

Source

impl Type1Blob

pub const HEADER: DeliveryBlobHeader

pub const CHUNKED_ARCHIVE_OPTIONS: ChunkedArchiveOptions

pub fn generate(data: &[u8], mode: CompressionMode) -> Vec<u8>

Generate a Type 1 delivery blob for data using the specified mode.

pub fn generate_to( data: &[u8], mode: CompressionMode, writer: impl Write, ) -> Result<(), Error>

Generate a Type 1 delivery blob for data using the specified mode. Writes delivery blob directly into writer.

pub fn parse( data: &[u8], ) -> Result<Option<(Type1Blob, &[u8])>, DeliveryBlobError>

Attempt to parse data as a Type 1 delivery blob. On success, returns validated blob info, and the remainder of data representing the blob payload.