pub struct Type2Blob {
pub header: DeliveryBlobHeader,
pub payload_length: usize,
pub is_compressed: bool,
}Expand description
Header + metadata fields of a Type 2 blob.
WARNING: Outside of storage-owned components, this should only be used for informational or debugging purposes. The contents of this struct should be considered internal implementation details and are subject to change at any time.
Fields
header: DeliveryBlobHeaderpayload_length: usizeis_compressed: boolImplementations
Sourceimpl Type2Blob
impl Type2Blob
pub const HEADER: DeliveryBlobHeader
pub const CHUNKED_ARCHIVE_OPTIONS: ChunkedArchiveOptions
Sourcepub fn generate(data: &[u8], mode: CompressionMode) -> Vec<u8> ⓘ
pub fn generate(data: &[u8], mode: CompressionMode) -> Vec<u8> ⓘ
Generate a Type 2 delivery blob for data using the specified mode.
Sourcepub fn generate_to(
data: &[u8],
mode: CompressionMode,
writer: impl Write,
) -> Result<(), Error>
pub fn generate_to( data: &[u8], mode: CompressionMode, writer: impl Write, ) -> Result<(), Error>
Generate a Type 2 delivery blob for data using the specified mode. Writes delivery blob
directly into writer.