pub struct Type3Blob {
pub header: DeliveryBlobHeader,
pub payload_length: usize,
pub is_compressed: bool,
}Expand description
Header + metadata fields of a Type 3 blob.
NOTE: Type 3 delivery blobs are currently UNSTABLE / EXPERIMENTAL and subject to change.
WARNING: Outside of storage-owned components, this should only be used for informational or debugging purposes. The contents of this struct should be considered internal implementation details and are subject to change at any time.
Fields
header: DeliveryBlobHeaderpayload_length: usizeis_compressed: boolImplementations
Sourceimpl Type3Blob
impl Type3Blob
pub const HEADER: DeliveryBlobHeader
pub const CHUNKED_ARCHIVE_OPTIONS: ChunkedArchiveOptions
Sourcepub fn generate(data: &[u8], mode: CompressionMode) -> Vec<u8> ⓘ
pub fn generate(data: &[u8], mode: CompressionMode) -> Vec<u8> ⓘ
Generate a Type 3 delivery blob for data using the specified mode.
Sourcepub fn generate_to(
data: &[u8],
mode: CompressionMode,
writer: impl Write,
) -> Result<(), Error>
pub fn generate_to( data: &[u8], mode: CompressionMode, writer: impl Write, ) -> Result<(), Error>
Generate a Type 3 delivery blob for data using the specified mode. Writes delivery blob
directly into writer.