pub struct StreamingDecompressor<C, B> { /* private fields */ }Expand description
Stateful streaming decompressor that receives compressed block buffers
and decompresses complete chunks into dest_buf.
Implementations
Sourceimpl<C: Borrow<CompressionInfo>, B: DataBuffer> StreamingDecompressor<C, B>
impl<C: Borrow<CompressionInfo>, B: DataBuffer> StreamingDecompressor<C, B>
Sourcepub fn new(
info: C,
range: Range<u64>,
uncompressed_size: u64,
dest_buf: B,
) -> Result<(Self, Range<u64>), ChunkedArchiveError>
pub fn new( info: C, range: Range<u64>, uncompressed_size: u64, dest_buf: B, ) -> Result<(Self, Range<u64>), ChunkedArchiveError>
Creates a new streaming decompressor for range into dest_buf.
Accepts any container info implementing Borrow<CompressionInfo> (e.g.
&CompressionInfo or Arc<CompressionInfo>).
Returns the decompressor and the block-aligned compressed byte range (Range<u64>) to
read from storage.
range.start must be chunk aligned (a multiple of chunk_size).
Sourcepub fn push<'b>(
&mut self,
buffer_slice: impl Into<PtrByteSlice<'b>>,
) -> Result<(), ChunkedArchiveError>
pub fn push<'b>( &mut self, buffer_slice: impl Into<PtrByteSlice<'b>>, ) -> Result<(), ChunkedArchiveError>
Pushes a newly read compressed block buffer slice and decompresses any complete chunks.
Fuses on error: if an error occurs or has previously occurred, returns Err.