pub fn delivery_blob_type(
data: &[u8],
) -> Result<DeliveryBlobType, DecompressError>Expand description
Returns the type of delivery blob represented by data.
Returns an error if data is too short to contain a valid header.
Note: Only the header portion of the delivery blob needs to be present
in data (the full payload is not required).